@@ -106,12 +106,11 @@ class Clock():
         self.resize_requested = True
 
     def set_alarm_enabled(self, b):
-        if (not self.alarm_enabled) and b and self.alarm_indicator_enabled :
-            self.alarm_enabled = b
-        else :
-            self.alarm_enabled = False
-
-        self.request_resize()
+        old_state = self.alarm_enabled
+        self.alarm_enabled = b
+ 
+        if (old_state != self.alarm_enabled) and self.alarm_indicator_enabled :
+            self.request_resize()
 
     def set_alarm_indicator_enabled(self, b):
         self.alarm_indicator_enabled = b
