@@ -48,7 +48,7 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         hildondesktop.StatusMenuItem.__init__(self)
 
         self.active = True
-        self.clock_style = 0
+        self.clock_name = "DecimalClock"
 
         self.time = None
         self.old_time = None
@@ -67,8 +67,8 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         self.set_status_area_widget(self.drawing_area)
       	self.drawing_area.show()
 
-        self.clock = getattr(clocks[self.clock_style], clock_names[self.clock_style])(self.drawing_area)
-        self.clock.resize()
+        self.clock = getattr(clocks[clock_names.index(self.clock_name)], self.clock_name)(self.drawing_area)
+        self.clock.request_resize()
 
         self.show()
 
@@ -112,7 +112,7 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         self.style_button = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
         self.style_button.set_title("Clock Style")
         self.style_button.set_selector(selector)
-        self.style_button.set_active(self.clock_style)
+        self.style_button.set_active(clock_names.index(self.clock_name))
         vb.pack_start(self.style_button, True, True, 0)
         self.style_button.show()
 
@@ -170,10 +170,10 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         dialog.show_all()
 
     def settings_ok_cb(self, widget, dialog):
-        self.clock_style = self.style_button.get_active()
+        self.clock_name = clock_names[self.style_button.get_active()]
 
         old_clock = self.clock
-        self.clock = getattr(clocks[self.clock_style], clock_names[self.clock_style])(self.drawing_area)
+        self.clock = getattr(clocks[clock_names.index(self.clock_name)], self.clock_name)(self.drawing_area)
 
         self.clock.set_alarm_indicator_enabled(self.alarm_indicator_button.get_active())
         self.clock.set_show_seconds(self.show_seconds_button.get_active())
@@ -182,7 +182,7 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         self.clock.set_font_name(self.font_names[self.font_button.get_active()])
         self.clock.set_gdk_color(self.color_button.get_color())
 
-        self.clock.resize()
+        self.clock.request_resize()
 
         self.clock.set_alarm_enabled(old_clock.get_alarm_enabled())
         self.clock.set_alarm_time(old_clock.get_alarm_time())
